@@ -1314,9 +1314,8 @@ void SciTEBase::SetFileStackMenu() {
 				GUI::gui_string sEntry;
 
 #if defined(_WIN32) || defined(GTK)
-				GUI::gui_string sPos = GUI::StringFromInteger((stackPos + 1) % 10);
-				GUI::gui_string sHotKey = GUI_TEXT("&") + sPos + GUI_TEXT(" ");
-				sEntry = sHotKey;
+				const GUI::gui_string sPos = GUI::StringFromInteger((stackPos + 1) % 10);
+				sEntry = GUI_TEXT("&") + sPos + GUI_TEXT(" ");
 #endif
 
 				const GUI::gui_string path = EscapeFilePath(
@@ -1442,7 +1441,7 @@ void SciTEBase::StackMenuPrev() {
 					rf = rfLast;
 					rfLast.Init();
 				} else {
-					rf = rfCurrent;
+					rf = std::move(rfCurrent);
 					break;
 				}
 			}
