@@ -38,6 +38,18 @@
 using namespace Scintilla;
 using namespace Scintilla::Internal;
 
+#if !defined(_WIN32) && !defined(NO_CXX11_REGEX)
+// set global locale to pass std::regex related tests
+// see https://gcc.gnu.org/bugzilla/show_bug.cgi?id=63776
+struct GlobalLocaleInitializer {
+	GlobalLocaleInitializer() {
+		try {
+			std::locale::global(std::locale("en_US.UTF-8"));
+		} catch (...) {}
+	}
+} globalLocaleInitializer;
+#endif
+
 // Test Document.
 
 struct Folding {
@@ -143,6 +155,7 @@ TEST_CASE("Document") {
 		REQUIRE(1 == doc.document.LinesTotal());
 		REQUIRE(0 == doc.document.LineStart(0));
 		REQUIRE(0 == doc.document.LineFromPosition(0));
+		REQUIRE(0 == doc.document.LineStartPosition(0));
 		REQUIRE(sLength == doc.document.LineStart(1));
 		REQUIRE(0 == doc.document.LineFromPosition(static_cast<int>(sLength)));
 		REQUIRE(doc.document.CanUndo());
@@ -453,6 +466,52 @@ TEST_CASE("Document") {
 		REQUIRE(doc.NextPosition(15, -1) == 14);
 	}
 
+	SECTION("RegexSearchAndSubstitution") {
+		DocPlus doc("\n\r\r\n 1a\xCE\x93z \n\r\r\n 2b\xCE\x93y \n\r\r\n", CpUtf8);// 1a gamma z 2b gamma y
+		const std::string finding = R"(\d+(\w+))";
+		Sci::Position lengthFinding = finding.length();
+		Sci::Position location = doc.FindNeedle(finding, FindOption::RegExp | FindOption::Posix, &lengthFinding);
+		REQUIRE(location == 5);
+		REQUIRE(lengthFinding == 5);
+
+		const std::string_view substituteText = R"(\t\1\n)";
+		Sci::Position lengthsubstitute = substituteText.length();
+		std::string substituted = doc.document.SubstituteByPosition(substituteText.data(), &lengthsubstitute);
+		REQUIRE(lengthsubstitute == 6);
+		REQUIRE(substituted == "\ta\xCE\x93z\n");
+
+		lengthFinding = finding.length();
+		location = doc.FindNeedleReverse(finding, FindOption::RegExp | FindOption::Posix, &lengthFinding);
+		REQUIRE(location == 16);
+		REQUIRE(lengthFinding == 5);
+
+		lengthsubstitute = substituteText.length();
+		substituted = doc.document.SubstituteByPosition(substituteText.data(), &lengthsubstitute);
+		REQUIRE(lengthsubstitute == 6);
+		REQUIRE(substituted == "\tb\xCE\x93y\n");
+
+		#ifndef NO_CXX11_REGEX
+		lengthFinding = finding.length();
+		location = doc.FindNeedle(finding, FindOption::RegExp | FindOption::Cxx11RegEx, &lengthFinding);
+		REQUIRE(location == 5);
+		REQUIRE(lengthFinding == 5);
+
+		lengthsubstitute = substituteText.length();
+		substituted = doc.document.SubstituteByPosition(substituteText.data(), &lengthsubstitute);
+		REQUIRE(lengthsubstitute == 6);
+		REQUIRE(substituted == "\ta\xCE\x93z\n");
+
+		lengthFinding = finding.length();
+		location = doc.FindNeedleReverse(finding, FindOption::RegExp | FindOption::Cxx11RegEx, &lengthFinding);
+		REQUIRE(location == 16);
+		REQUIRE(lengthFinding == 5);
+
+		lengthsubstitute = substituteText.length();
+		substituted = doc.document.SubstituteByPosition(substituteText.data(), &lengthsubstitute);
+		REQUIRE(lengthsubstitute == 6);
+		REQUIRE(substituted == "\tb\xCE\x93y\n");
+		#endif
+	}
 }
 
 TEST_CASE("Words") {
